@@ -32,43 +32,43 @@ async def mint_helper(keypair, log_level, class_enum):
     print("Mint_Id: ", mint_keypair.public_key)
     t_dets = await mint_nft(payer_keypair, mint_keypair, class_enum, client, log_level)
     print(t_dets)
-    await client.close()
+    client.close()
 
 @click.command(name="Benitoite")
 @click.option('--keypair', default = 'keypair.json')
 @click.option('--log_level', default = '2')
 async def Benitoite(keypair, log_level: int = 0):
-    await mint_helper(keypair, log_level, ClassEnum.enum.Benitoite())
+    mint_helper(keypair, log_level, ClassEnum.enum.Benitoite())
 
 @click.command(name="Serendibite")
 @click.option('--keypair', default = 'keypair.json')
 @click.option('--log_level', default = '2')
 async def Serendibite(keypair, log_level: int = 0):
-    await mint_helper(keypair, log_level, ClassEnum.enum.Serendibite())
+    mint_helper(keypair, log_level, ClassEnum.enum.Serendibite())
 
 @click.command(name="Sapphire")
 @click.option('--keypair', default = 'keypair.json')
 @click.option('--log_level', default = '2')
 async def Sapphire(keypair, log_level: int = 0):
-    await mint_helper(keypair, log_level, ClassEnum.enum.Sapphire())
+    mint_helper(keypair, log_level, ClassEnum.enum.Sapphire())
 
 @click.command(name="Emerald")
 @click.option('--keypair', default = 'keypair.json')
 @click.option('--log_level', default = '2')
 async def Emerald(keypair, log_level: int = 0):
-    await mint_helper(keypair, log_level, ClassEnum.enum.Emerald())
+    mint_helper(keypair, log_level, ClassEnum.enum.Emerald())
 
 @click.command(name="Diamond")
 @click.option('--keypair', default = 'keypair.json')
 @click.option('--log_level', default = '2')
 async def Diamond(keypair, log_level: int = 0):
-    await mint_helper(keypair, log_level, ClassEnum.enum.Diamond())
+    mint_helper(keypair, log_level, ClassEnum.enum.Diamond())
 
 @click.command(name="Ruby")
 @click.option('--keypair', default = 'keypair.json')
 @click.option('--log_level', default = '2')
 async def Ruby(keypair, log_level: int = 0):
-    await mint_helper(keypair, log_level, ClassEnum.enum.Ruby())
+    mint_helper(keypair, log_level, ClassEnum.enum.Ruby())
 
 mint.add_command(Benitoite)
 mint.add_command(Serendibite)
@@ -94,7 +94,7 @@ async def create_val_proposal(keypair, log_level: int = 0):
     numeration = GlobalGems.parse(gem_info.value.data).proposal_numeration
     t_dets = await create_validator_proposal(payer_keypair, numeration, client, log_level)
     print(t_dets)
-    await client.close()
+    client.close()
 
 '''
 Now Deprecated, do not use. Use create_vote_account instead.
@@ -132,7 +132,7 @@ async def reg_validator(validator_keypair, keypair, log_level: int = 0):
     print("Validator Key: ", validator_keypair.public_key)
     t_dets = await register_validator_id(payer_keypair, PubkeyInput(pubkey = validator_keypair.public_key), client, log_level)
     print(t_dets)
-    await client.close()
+    client.close()
 
 @click.command(name="init_rebalance")
 @click.argument('vote_key')
@@ -147,7 +147,7 @@ async def initialize_rebalancing(vote_key, keypair, log_level: int = 0):
     vote_account_id = parse_pubkey_input(vote_key)
     t_dets = await init_rebalance(payer_keypair, vote_account_id, client, log_level)
     print(t_dets)
-    await client.close()
+    client.close()
 
 @click.command(name="finalize_rebalance")
 @click.argument('vote_key')
@@ -162,7 +162,7 @@ async def finalize_rebalancing(vote_key, keypair, log_level: int = 0):
     vote_account_id = parse_pubkey_input(vote_key)
     t_dets = await finalize_rebalance(payer_keypair, vote_account_id, client, log_level)
     print(t_dets)
-    await client.close()
+    client.close()
 
 @click.command(name="init")
 @click.option('--keypair', default = 'keypair.json')
@@ -175,7 +175,7 @@ async def ingl(keypair, log_level: int = 0):
     payer_keypair = parse_keypair_input(f"./{keypair}")
     t_dets = await ingl_init(payer_keypair, client, log_level)
     print(t_dets)
-    await client.close()
+    client.close()
 
 @click.command(name="close_proposal")
 @click.option('--keypair', default = 'keypair.json')
@@ -191,7 +191,7 @@ async def close_val_proposal(keypair, log_level: int = 0):
     numeration = GlobalGems.parse(gem_info.value.data).proposal_numeration
     t_dets = await close_proposal(payer_keypair, numeration-1, client, log_level)
     print(t_dets)
-    await client.close()
+    client.close()
 
 @click.command(name="process_rewards")
 @click.option('--keypair', default = 'keypair.json')
@@ -206,7 +206,7 @@ async def process_vote_account_rewards(keypair, vote_key, log_level: int = 0):
     vote_account_id = parse_pubkey_input(vote_key)
     t_dets = await process_rewards(payer_keypair, vote_account_id, client, log_level)
     print(t_dets)
-    await client.close()
+    client.close()
 
 @click.command(name='create_vote_account')
 @click.argument('val_keypair')
@@ -222,7 +222,7 @@ async def process_create_vote_account(val_keypair, log_level: int = 0):
     numeration = GlobalGems.parse(gem_info.value.data).proposal_numeration
     t_dets = await create_vote_account(payer_keypair, numeration-1, client, log_level)
     print(t_dets)
-    await client.close()
+    client.close()
 
 @click.command(name='create_upgrade_proposal')
 @click.argument('buffer')
@@ -243,7 +243,7 @@ async def process_create_upgrade_proposal(keypair, buffer, code_link, log_level:
     numeration = GlobalGems.parse(gem_info.value.data).upgrade_proposal_numeration
     t_dets = await create_program_upgrade_proposal(payer_keypair, buffer_address, numeration, code_link, client, log_level)
     print(t_dets)
-    await client.close()
+    client.close()
 
 @click.command(name='create_upgrade_proposal')
 @click.argument('vote')
@@ -263,7 +263,7 @@ async def process_vote_upgrade_proposal(keypair, vote, proposal, vote_account, l
     print(f"Vote_account: {vote_account_key}, Proposal_Account {upgrade_proposal_pubkey}, Vote: {'Approve' if vote else 'Dissaprove'} ");
     t_dets = await vote_program_upgrade_proposal(payer_keypair, vote, upgrade_proposal_pubkey, upgrade_proposal_numeration, vote_account_key, vote_account_numeration, client, log_level)
     print(t_dets)
-    await client.close()
+    client.close()
 
 @click.command(name='create_upgrade_proposal')
 @click.argument('proposal')
@@ -279,7 +279,7 @@ async def process_finalize_upgrade_proposal(keypair, proposal, log_level: int =
     print(f"Proposal_Account {upgrade_proposal_pubkey}");
     t_dets = await finalize_program_upgrade_proposal(payer_keypair, upgrade_proposal_pubkey, upgrade_proposal_numeration, client, log_level)
     print(t_dets)
-    await client.close()    
+    client.close()    
 
 
 @click.command(name="get_vote_pubkey")
