@@ -1,5 +1,4 @@
-from collections import String
-from state import *
+from .state import *
 
 def parse_vote(vote: str) -> bool:
     vote = vote.lower()
